######
apiref
######

.. readme_about_start

**apiref** is a library that makes it easy to document your API endpoints using
simple decorators.


Install
=======

.. code-block:: bash

    $ pip install apiref


.. readme_about_end


Useful Links
============

- `Documentation <https://novopl.github.io/apiref>`_
- `Source Code <https://github.com/novopl/apiref>`_
- `CI Builds <https://circleci.com/gh/novopl/apiref>`_
